@@ -22,22 +22,20 @@
 
 #include "mdwmoveaction.h"
 
-// KDE
-#include <kicon.h>
-
 //KMix
 #include "core/mixdevice.h"
 
 // Qt
+#include <QIcon>
 #include <QString>
 
 MDWMoveAction::MDWMoveAction(shared_ptr<MixDevice> md, QObject *parent)
- : KAction(parent), m_mixDevice(md)
+ : QAction(parent), m_mixDevice(md)
 {
    Q_ASSERT(md);
 
    setText(m_mixDevice->readableName());
-   setIcon(KIcon(m_mixDevice->iconName()));
+   setIcon(QIcon::fromTheme(m_mixDevice->iconName()));
    connect(this, SIGNAL(triggered(bool)), SLOT(triggered(bool)));
 }
 
